<?php
require('fpdf/fpdf.php');
require '../config.php';
require '../functions.php';

// Obtener datos de la empresa
$sql = "SELECT * FROM empresa WHERE id_empresa = 1";
$stmt = $pdo->query($sql);
$empresa = $stmt->fetch(PDO::FETCH_ASSOC);

// Obtener pagos en el rango de fechas
$fechaInicio = isset($_GET['fecha_inicio']) ? $_GET['fecha_inicio'] : '1900-01-01';
$fechaFin = isset($_GET['fecha_fin']) ? $_GET['fecha_fin'] : '2100-12-31';

$sql = "SELECT p.*, c.nombre AS nombre_cliente, c.apellido AS apellido_cliente, u.nombre AS nombre_usuario, u.apellido AS apellido_usuario 
        FROM pagos p 
        JOIN clientes c ON p.id_cliente = c.id_cliente 
        JOIN usuarios u ON p.id_usuario = u.id_usuario 
        WHERE p.fecha_pago BETWEEN :fecha_inicio AND :fecha_fin
        ORDER BY p.fecha_pago";
$stmt = $pdo->prepare($sql);
$stmt->execute(['fecha_inicio' => $fechaInicio, 'fecha_fin' => $fechaFin]);
$pagos = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Crear instancia de FPDF
$pdf = new FPDF('L', 'mm', 'A4');  // L para orientación horizontal
$pdf->AddPage();

// Encabezado
$pdf->SetFont('Arial', 'B', 10);  // Fuente más pequeña para el encabezado
$pdf->SetXY(10, 10);  // Ajustar posición del encabezado
$pdf->Image('../img/' . htmlspecialchars($empresa['logo']), 10, 10, 30);  // Ajustar tamaño y posición del logo

// Datos de la empresa
$pdf->SetFont('Arial', 'B', 12);  // Nombre de la empresa en fuente más grande
$pdf->SetX(50);  // Posicionar el cursor a la derecha del logo
$pdf->Cell(0, 10, utf8_decode($empresa['nombre']), 0, 1, 'C');
$pdf->SetFont('Arial', '', 10);  // Fuente normal para el resto de los datos
$pdf->Cell(0, 10, utf8_decode($empresa['estado'] . ', ' . $empresa['ciudad'] . ', ' . $empresa['direccion']), 0, 1, 'C');
$pdf->Cell(0, 10, utf8_decode('Teléfono: ' . $empresa['telefono'] . ' | Email: ' . $empresa['email']), 0, 1, 'C');
$pdf->Ln(10);

// Línea gris antes del título
$pdf->SetDrawColor(169, 169, 169); // Color gris
$pdf->Line(20, 50, 270, 50); // Coordenadas para la línea horizontal en orientación horizontal
$pdf->Ln(10); // Espacio debajo de la línea

// Título del informe
$pdf->SetFont('Arial', 'B', 14);  // Fuente más grande para el título
$pdf->Cell(0, 10, utf8_decode('Informe de Pagos'), 0, 1, 'C');
$pdf->Ln(5);  // Espacio debajo del título

// Encabezado de la tabla
$pdf->SetFont('Arial', 'B', 10);
$pdf->SetFillColor(169, 169, 169);  // Color de fondo gris para los encabezados
$pdf->Cell(20, 10, utf8_decode('ID Pago'), 1, 0, 'C', true);
$pdf->Cell(60, 10, utf8_decode('Cliente'), 1, 0, 'C', true);
$pdf->Cell(30, 10, utf8_decode('Fecha de Pago'), 1, 0, 'C', true);
$pdf->Cell(40, 10, utf8_decode('Método de Pago'), 1, 0, 'C', true);
$pdf->Cell(30, 10, utf8_decode('Monto'), 1, 0, 'C', true);
$pdf->Cell(30, 10, utf8_decode('Estado'), 1, 0, 'C', true);
$pdf->Cell(60, 10, utf8_decode('Usuario'), 1, 1, 'C', true);  // Añadir 1 al final para nueva línea

// Datos de la tabla
$pdf->SetFont('Arial', '', 10);
$pdf->SetFillColor(255, 255, 255);  // Color de fondo blanco para las filas de datos
$totalMonto = 0;
foreach ($pagos as $pago) {
    $pdf->Cell(20, 10, utf8_decode($pago['id_pago']), 1);
    $pdf->Cell(60, 10, utf8_decode($pago['nombre_cliente'] . ' ' . $pago['apellido_cliente']), 1);

    // Formatear la fecha para mostrar solo la parte de la fecha
    $fechaPago = date('Y-m-d', strtotime($pago['fecha_pago']));
    $pdf->Cell(30, 10, utf8_decode($fechaPago), 1);
    $pdf->Cell(40, 10, utf8_decode($pago['metodo_pago']), 1);

    // Añadir símbolo de la moneda y formatear el monto
    $monto = number_format($pago['monto'], 2);
    $pdf->Cell(30, 10, utf8_decode(formatMonto($moneda, $monto)), 1);
    $pdf->Cell(30, 10, utf8_decode($pago['estado']), 1);
    $pdf->Cell(60, 10, utf8_decode($pago['nombre_usuario'] . ' ' . $pago['apellido_usuario']), 1);  // Mover Usuario a la última columna
    $pdf->Ln();
    $totalMonto += $pago['monto'];
}

// Total de la columna Monto
$pdf->SetFont('Arial', 'B', 10);
$pdf->Cell(150, 10, utf8_decode('Total'), 1);
$pdf->Cell(30, 10, utf8_decode($empresa['moneda'] . ' ' . number_format($totalMonto, 2)), 1);

// Output del PDF
$pdf->Output();
?>
